==> httraqt_1.2.0.orig.tar.gz: httraqt/sources/options/includes/BuildStringDialog.h <==
/***************************************************************************
 * C++ Implementation:                                                     *
 * Copyright (C) 2012 by Eduard Kalinowski                                 *
 * Germany, Lower Saxony, Hanover                                          *
 * eduard_kalinowski@yahoo.de                                              *
 *                                                                         *
 * HTTraQt is free software; you can redistribute it and/or                *
 * modify it under the terms of the GNU Lesser General Public              *
 * License as published by the Free Software Foundation; either            *
 * version 3 of the License, or (at your option) any later version.        *
 *                                                                         *
 * HTTraQt is distributed in the hope that it will be useful, but          *
 * WITHOUT ANY WARRANTY; without even the implied warranty of              *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                    *
 *                                                                         *
 * See the GNU Lesser General Public License for more details.             *
 *                                                                         *
 * You should have received a copy of the GNU Lesser General Public        *
 * License along with HTTraQt. If not, see  http://www.gnu.org/licenses    *
 ***************************************************************************/

#ifndef BUILDSTRING_H
#define BUILDSTRING_H

#include "../../main/includes/httraqt.h"
#include "ui_BuildStringDialog.h"

class HTTraQt;


class BuildStringDialog: public QDialog, public Ui_BuildStringDialog
{
        Q_OBJECT
    public:
        BuildStringDialog(QWidget *parent = 0);
        void initTextPoints();

    private:
        HTTraQt* parent;

    private slots:
        void onOk();

};

#endif

==> httraqt_1.3.0.orig.tar.gz: httraqt/sources/options/includes/BuildStringDialog.h <==
/***************************************************************************
 * C++ Implementation:                                                     *
 * Copyright (C) 2012 by Eduard Kalinowski                                 *
 * Germany, Lower Saxony, Hanover                                          *
 * eduard_kalinowski@yahoo.de                                              *
 *                                                                         *
 * HTTraQt is free software; you can redistribute it and/or                *
 * modify it under the terms of the GNU Lesser General Public              *
 * License as published by the Free Software Foundation; either            *
 * version 3 of the License, or (at your option) any later version.        *
 *                                                                         *
 * HTTraQt is distributed in the hope that it will be useful, but          *
 * WITHOUT ANY WARRANTY; without even the implied warranty of              *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                    *
 *                                                                         *
 * See the GNU Lesser General Public License for more details.             *
 *                                                                         *
 * You should have received a copy of the GNU Lesser General Public        *
 * License along with HTTraQt. If not, see  http://www.gnu.org/licenses    *
 ***************************************************************************/

#ifndef BUILDSTRING_H
#define BUILDSTRING_H

#include "../../main/includes/httraqt.h"
#include "ui_BuildStringDialog.h"

class HTTraQt;


class BuildStringDialog: public QDialog, public Ui::BuildStringDialog, public Translator
{
        Q_OBJECT
    public:
        BuildStringDialog(QWidget *parent = 0);
        void initTextPoints();

    private:
        HTTraQt* parent;

    private slots:
        void onOk();

};

#endif
